@@ -142,9 +142,15 @@ def __logging_dict_to_keyids__(config_dict):
         core.KeyId.CFG_NAVSPG_USE_PPP : smoothing,
         core.KeyId.CFG_RATE_MEAS : int(rate * 1000), # s -> ms
         core.KeyId.CFG_MSGOUT_UBX_RXM_RAWX_USB : measurements,
+        core.KeyId.CFG_MSGOUT_UBX_RXM_RAWX_UART1 : measurements,
+        core.KeyId.CFG_MSGOUT_UBX_RXM_RAWX_UART2 : measurements,
         #core.KeyId.CFG_RATE_NAV : rate,
         core.KeyId.CFG_MSGOUT_UBX_NAV_POSECEF_USB : solutions, 
-        core.KeyId.CFG_MSGOUT_UBX_RXM_SFRBX_USB : ephemeris
+        core.KeyId.CFG_MSGOUT_UBX_NAV_POSECEF_UART1 : solutions, 
+        core.KeyId.CFG_MSGOUT_UBX_NAV_POSECEF_UART2 : solutions, 
+        core.KeyId.CFG_MSGOUT_UBX_RXM_SFRBX_USB : ephemeris,
+        core.KeyId.CFG_MSGOUT_UBX_RXM_SFRBX_UART1 : ephemeris,
+        core.KeyId.CFG_MSGOUT_UBX_RXM_SFRBX_UART2 : ephemeris
     }
 
     return out
