@@ -542,7 +542,11 @@ class KeyId(enum.Enum):
     CFG_MSGOUT_UBX_RXM_RAWX_USB = 0x209102a7
     CFG_MSGOUT_UBX_RXM_RAWX_SPI = 0x209102a8
 
+    CFG_MSGOUT_UBX_NAV_POSECEF_UART1 = 0x20910025
+    CFG_MSGOUT_UBX_NAV_POSECEF_UART2 = 0x20910026
     CFG_MSGOUT_UBX_NAV_POSECEF_USB = 0x20910027
+    CFG_MSGOUT_UBX_RXM_SFRBX_UART1 = 0x20910232
+    CFG_MSGOUT_UBX_RXM_SFRBX_UART2 = 0x20910233
     CFG_MSGOUT_UBX_RXM_SFRBX_USB = 0x20910234
 
     CFG_MSGOUT_NMEA_ID_GSA_I2C = 0x209100bf
